{% load i18n %}
{% load crispy_forms_tags %}
<h3 class="fs-5 oxanium text-center">{% trans "Category" %}</h3>
<div id="formset">
    {{ formset.management_form }}
        {% for form in formset %}
        <div id="form-0" class="formset pt-2">
            {{form|crispy}}
            {{form|as_crispy_errors}}
        </div>
        {% endfor %}
    <div id="empty-form" class="d-none">
        {{formset.empty_form.media}}
        {{formset.empty_form|crispy}}
    </div>
</div>
<div class="d-flex justify-content-between my-3">
    <button class="btn-clear" type="button" onclick="addFormset()"><i class="fa-solid fa-plus"></i> {% trans " Add" %}</button>
    <button class="btn-clear" type="button" onclick="clearFormset()"><i class="fa-solid fa-minus"></i> {% trans "Remove" %}</button>
</div>
<p class="response-footer text-link fw-bold oxanium"></p>
<input type="hidden" name="form-id" value="catalogForm">